#
# spec file for package python-pegasus-wms.api
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-pegasus-wms.api
Version:        5.0.6
Release:        1.4
Summary:        Pegasus Workflow Management System Python API
License:        Apache-2.0
URL:            http://pegasus.isi.edu
Source0:        pegasus-wms.api-gh-%{version}.tar.xz
Source1:        pegasus-schema-yaml-%{version}.tar.xz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module pegasus-wms.common}
BuildRequires:  %{python_module jsonschema}
BuildRequires:  %{python_module pytest-mock}
BuildRequires:  %{python_module pytest}
# /SECTION
BuildRequires:  fdupes
Requires:       python-pegasus-wms.common
BuildArch:      noarch
%python_subpackages

%description
This package contains the Python APIs for Pegasus WMS, including:

The DAX API (Versions 2 and 3)
The PDAX API (Version 2)
The monitoring API
The Stampede database API
The Pegasus statistics API
The Pegasus plots API
Misc. Pegasus utilities
The pegasus service, including the ensemble manager and dashboard

%prep
%setup -q -n pegasus-wms.api-gh-%{version} -b1
# replace ties to global git repository with our limited package subset
sed -i 's|version=read_version(),|version="%{version}",|' setup.py
# replaces paths in two lines
sed -i test/api/conftest.py \
  -e 's|"packages/pegasus-api/test/api"|"pegasus-wms.api-gh-%{version}/test/api"|' \
  -e 's|"share/pegasus/schema/yaml"|"pegasus-schema-yaml-%{version}"|'

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# same output but different order in 'uses' field (full name in one string is not excluded on Leap)
donttest="test_workflow and to_subworkflow_conversion_in_write"
%pytest -v -k "not ($donttest)"

%files %{python_files}
%doc README.md
%license LICENSE
%dir %{python_sitelib}/Pegasus
%{python_sitelib}/Pegasus/api
%{python_sitelib}/pegasus_wms.api-%{version}.dist-info

%changelog
* Fri Feb 16 2024 Ben Greiner <code@bnavigator.de>
- Update to 5.0.6
  * Improve stash integration to be osdf:// aware
  * Handle dagman no longer inheriting user environment for the
    dagman job
  * Add support for Arm 64 architecture (aarch64)
  * Enable host-wide metrics collection
  * File dependencies between sub workflow and compute jobs broken
  * Planner container mount point parsing breaks on . in the dir
    name
  * request_disk is incorrectly set to MBs instead of KBs
  * +DAGNodeRetry for attrib=value assigment breaks on HTondor
    10.0.x when direct submission is disabled
  * Data management between parent compute job and a sub workflow
    job broken
  * Inplace cleanup broken when a sub workflow job and a parent
    compute job has a data dependency
- Release Notes for Pegasus 5.0.5 []Incomplete clean between ant
  targets
- Release Notes for Pegasus 5.0.4
  * Support for HTCondor 10.2 series
  * Improved sub workflow file handling
  * pegasus-analyzer should show failing jobs
  * pegasus-analyzer should traverse all sub workflows
  * File dependencies for sub workflow jobs - differentiate inputs
    for planner use and those for sub workflow
  * update python api and json schema to expose forPlanning boolean
    attribute with files in uses section
  * update java wf api to support forPlanner attribute for files
  * handle condor_submit updated way of specifying environment in
    the .dag.condor.sub file
  * need to explicitly mount sharedfilesystem dir into container
    when using shared filesystem as staging site for nonsharedfs
  * worker package transfer into application containers
  * In pegasus lite scripts worker package strict check is turned
    off
  * update pegasus-configure-glite to use BLAHPD_LOCATION
* Sat Oct 29 2022 Ben Greiner <code@bnavigator.de>
- Update to 5.0.3
  * Support for Deep LFN’s in CondorIO Mode. If you are using
  bypass of staging for input files, then support for deep LFN’s
  depends on associated HTCondor ticket 1325 that will be fixed
  in HTCondor release 10.1.0.
  * Per Job Symlinking
  * New Containers exercise in the Pegasus Tutor
* Fri Jul  1 2022 Ben Greiner <code@bnavigator.de>
- Initial specfile for version 5.0.2
- Required by PyCBC
